@@ -1073,10 +1073,11 @@ class TestMerging(TestBase):
     def test_global_backend(self):
         self.generate('''network:
   version: 2
+  renderer: NetworkManager
   ethernets:
     engreen:
       dhcp4: y''',
-                      confs={'backend': 'network:\n  renderer: NetworkManager'})
+                      confs={'backend': 'network:\n  renderer: networkd'})
 
         self.assert_networkd({'engreen.network': ND_DHCP4 % 'engreen'})
         self.assert_nm(None, '''[keyfile]
@@ -1243,6 +1244,12 @@ UseMTU=true
 
         self.assert_networkd({'engreen.network': ND_DHCP4 % 'engreen',
                               'enred.link': '[Match]\nOriginalName=enred\n\n[Link]\nWakeOnLan=magic\n',
+                              'enred.network': '''[Match]
+Name=enred
+
+[Network]
+LinkLocalAddressing=ipv6
+''',
                               'enyellow.network': ND_DHCP4 % 'enyellow',
                               'enblue.network': ND_DHCP4 % 'enblue'})
 
